@@ -14,7 +14,7 @@
 """Grok
 """
 
-from zope.interface import implements
+from zope.interface import implements, implementsOnly, classProvides
 from zope.component import adapts
 
 from martian import ClassGrokker, InstanceGrokker, GlobalGrokker
@@ -22,8 +22,8 @@ from grokcore.component.components import Adapter, GlobalUtility, MultiAdapter,
 
 from martian import baseclass
 from grokcore.component.directive import (
-    context, name, title, description, provides, global_utility, direct)
-from grokcore.component.decorators import subscribe, adapter, implementer
+    context, name, title, description, provides, global_utility, global_adapter, direct)
+from grokcore.component.decorators import subscribe, adapter, implementer, provider
 from martian.error import GrokError, GrokImportError
 
 # Import this module so that it's available as soon as you import the
