@@ -57,6 +57,17 @@ class IDirectives(Interface):
 
     def implements(*interfaces):
         """Declare that a class implements the given interfaces."""
+    
+    def implementsOnly(*interfaces):
+        """Declare that a class implements only the given interfaces.
+        
+        Interfaces implemented by base classes are explicitly not inherited.
+        """
+    
+    def classProvides(*interfaces):
+        """Declare that a class (as opposed to instances of the class)
+        directly provides the given interfaces.
+        """
 
     def adapts(*classes_or_interfaces):
         """Declare that a class adapts objects of the given classes or
@@ -101,6 +112,15 @@ class IDirectives(Interface):
         name - the name of the utility
         """
 
+    def global_adapter(factory, adapts=None, provides=None, name=u''):
+        """Register a global adapter.
+
+        factory - the adapter factory, a callable
+        adapts - an interface or list of interfaces adapted
+        provides - the interface provided by the adapter
+        name - the name of the adapter
+        """
+
     def direct():
         """Specify whether the class should be used for the component
         or whether it should be used to instantiate the component.
@@ -126,6 +146,11 @@ class IDecorators(Interface):
         """Describes that a function that's used as an adapter
         implements an interface or a number of interfaces.
         """
+    
+    def provider(*interfaces):
+        """Describes that a function directly provides an interface or a
+        number of interfaces.
+        """
 
 
 class IGrokErrors(Interface):
